@@ -265,11 +265,12 @@ class PredefinedAITemplateTest:
             },
         }
         """
-        create_experiment_data["name"] = create_experiment_data["model"] + str(uuid.uuid4())
+        create_experiment_data["name"] = create_experiment_data["model"] + "_" + str(uuid.uuid4())
         res = requests.get(experiment_url, headers=self.request_header)
         if res.status_code != 200:
             raise Exception(f"Get experiment info failed. " f"reason: {res.text}")
 
+        print(f"experiment_name: {create_experiment_data['name']}")
         print(
             "send create experiment request to automl server. After creating experiments,"
             + "training will start."
